@@ -4,11 +4,15 @@ import json
 import zipfile
 import shutil
 import win32com.shell.shell as shell
+from multiprocessing.connection import Listener
 
-TASK_PARAMS_FILE_NAME = 'nowyou_task_params.txt'
+TASK_PARAMS_FILE_NAME = 'nowyou_task_params.json'
 PLUGIN_PATH_NAME = 'nowyou_autorun'
 PLUGIN_RESOURCES_PATH = 'resources'
 
+PROCESS_COMMUNICATION_PASSWORD = '9oB!jZabGhaE9lCNxj'
+PROCESS_COMMUNICATION_PORT = 6984
+
 
 def export_avatar(
         vstitcher_data_path: str,
@@ -26,23 +30,44 @@ def export_avatar(
         if os.path.exists(plugin_folder) and os.path.isdir(plugin_folder):
             shutil.rmtree(plugin_folder)
 
-        zip_ref.extractall(plugin_path)
+        zip_ref.extractall(plugin_folder)
 
     # set up task params
     params = {
         'body_sizes': body_sizes,
-        'work_path': work_path
+        'work_path': work_path,
     }
-    data = json.dumps(params)
 
     # save JSON params to file
-    with open(os.path.join(plugin_folder, PLUGIN_RESOURCES_PATH, TASK_PARAMS_FILE_NAME), 'w') as outfile:
-        json.dump(data, outfile)
+    task_param_file = os.path.join(plugin_folder, PLUGIN_RESOURCES_PATH, TASK_PARAMS_FILE_NAME)
+    with open(task_param_file, 'w') as outfile:
+        json.dump(params, outfile, indent=4)
+
 
     # launch VStitcher
     se_ret = shell.ShellExecuteEx(fMask=0x140, lpFile=r"{}".format(vstitcher_launcher_file), nShow=1)
 
     # wait for task finish
+    address = ('localhost', PROCESS_COMMUNICATION_PORT)
+    listener = Listener(address, authkey=PROCESS_COMMUNICATION_PASSWORD)
+    conn = listener.accept()
+    output_name = ''
+    while True:
+        msg = conn.recv()
+        # do something with msg
+        if msg == 'done':
+            output_name = msg
+            break
+
+    conn.close()
+    listener.close()
+
     # close VStitcher
+    os.system("taskkill /f /im VStitcher.exe")
+
     # delete plugin
+    if os.path.exists(plugin_folder) and os.path.isdir(plugin_folder):
+        shutil.rmtree(plugin_folder)
+
     # process result
+    return output_name
